@@ -7,7 +7,7 @@
 # This code extracts plain text from string tags on uncompressed Dia
 # diagrams.
 #
-# Copyright (c) 2004 by Jordi Vilalta  <jvprat@gmail.com>
+# Copyright (c) 2004 by Jordi Vilalta  <jvprat@wanadoo.es>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,20 +21,17 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
 ########################################################################
 
-=encoding UTF-8
-
 =head1 NAME
 
-Locale::Po4a::Dia - convert uncompressed Dia diagrams from/to PO files
+Locale::Po4a::Dia - Convert uncompressed Dia diagrams from/to PO files
 
 =head1 DESCRIPTION
 
-The po4a (PO for anything) project goal is to ease translations (and more
+The po4a (po for anything) project goal is to ease translations (and more
 interestingly, the maintenance of translations) using gettext tools on
 areas where they were not expected like documentation.
 
@@ -66,14 +63,14 @@ L<po4a(7)|po4a.7>, L<Locale::Po4a::TransTractor(3pm)>, L<Locale::Po4a::Xml(3pm)>
 
 =head1 AUTHORS
 
- Jordi Vilalta <jvprat@gmail.com>
+ Jordi Vilalta <jvprat@wanadoo.es>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2004 by Jordi Vilalta  <jvprat@gmail.com>
+Copyright (c) 2004 by Jordi Vilalta  <jvprat@wanadoo.es>
 
 This program is free software; you may redistribute it and/or modify it
-under the terms of GPL (see the COPYING file).
+under the terms of GPL (see COPYING file).
 
 =cut
 
@@ -93,14 +90,15 @@ sub initialize {
 	my %options = @_;
 
 	$self->SUPER::initialize(%options);
-	$self->{options}{'nostrip'}=1;
-	$self->{options}{'_default_translated'}.=' <dia:string>';
+	$self->{options}{'tagsonly'}=1;
+	$self->{options}{'tags'}.=' <dia:string>';
 	$self->treat_options;
+	# Force the output po to be in utf-8
+	$self->{TT}{po_out}->set_charset("utf-8")
 }
 
 sub found_string {
 	my ($self,$text,$ref,$options)=@_;
-	return $text if $text =~ m/^\s*$/s;
 
 	#We skip the paper type string
 	if ( $self->get_path() !~ /<dia:diagramdata>/ ) {
