@@ -7,7 +7,7 @@
 # This code extracts plain text from tags and attributes on Guide XML
 # documents.
 #
-# Copyright (c) 2004 by Jordi Vilalta  <jvprat@gmail.com>
+# Copyright (c) 2004 by Jordi Vilalta  <jvprat@wanadoo.es>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,20 +21,17 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
 ########################################################################
 
-=encoding UTF-8
-
 =head1 NAME
 
-Locale::Po4a::Guide - convert Guide XML documents from/to PO files
+Locale::Po4a::Guide - Convert Guide XML documents from/to PO files
 
 =head1 DESCRIPTION
 
-The po4a (PO for anything) project goal is to ease translations (and more
+The po4a (po for anything) project goal is to ease translations (and more
 interestingly, the maintenance of translations) using gettext tools on
 areas where they were not expected like documentation.
 
@@ -58,14 +55,14 @@ L<po4a(7)|po4a.7>, L<Locale::Po4a::TransTractor(3pm)>, L<Locale::Po4a::Xml(3pm)>
 
 =head1 AUTHORS
 
- Jordi Vilalta <jvprat@gmail.com>
+ Jordi Vilalta <jvprat@wanadoo.es>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2004 by Jordi Vilalta  <jvprat@gmail.com>
+Copyright (c) 2004 by Jordi Vilalta  <jvprat@wanadoo.es>
 
 This program is free software; you may redistribute it and/or modify it
-under the terms of GPL (see the COPYING file).
+under the terms of GPL (see COPYING file).
 
 =cut
 
@@ -86,66 +83,33 @@ sub initialize {
 
 #TODO: <include href="..."> includes a file
 	$self->SUPER::initialize(%options);
-	$self->{options}{'_default_translated'}.='
+	$self->{options}{'strip'}=1;
+	$self->{options}{'tagsonly'}=1;
+	$self->{options}{'tags'}.='
 		w<abstract>
-		<author>
-		<b>
-		<brite>
-		<c>
 		<codenote>
 		<comment>
-		<const>
 		<date>
-		w<dd>
-		w<dt>
-		<e>
-		<i>
-		<ident>
-		w<impo>
-		<keyword>
-		w<li>
-		<mail>
-		w<note>
+		<impo>
+		<li>
+		<note>
 		w<p>
-		<path>
 		W<pre>
-		<stmt>
-		<sub>
-		w<subtitle>
-		w<summary>
-		<sup>
-		w<th>
-		w<ti>
-		w<title>
-		<uri>
-		<var>
-		<version>
-		w<warn>';
-	$self->{options}{'_default_attributes'}.='
+		<th>
+		<ti>
+		<title>
+		<warn>';
+	$self->{options}{'attributes'}.='
 		<author>title
 		<figure>caption
-		<figure>link
 		<figure>short
-		<guide>lang
 		<guide>link
-		<p>by
 		<pre>caption';
-	$self->{options}{'_default_inline'}.='
-		<b>
-		<brite>
+	$self->{options}{'inline'}.='
 		<c>
-		<const>
 		<e>
 		<i>
-		<ident>
-		<img>
-		<keyword>
-		<mail>
 		<path>
-		<stmt>
-		<sub>
-		<sup>
-		<uri>
-		<var>';
+		<uri>';
 	$self->treat_options;
 }
