@@ -1,11 +1,13 @@
 # Locale::Po4a::Pod -- Convert POD data to PO file, for translation.
-# $Id: Pod.pm,v 1.23 2009-03-23 20:43:50 nekral-guest Exp $
+# $Id: Pod.pm,v 1.13 2004/08/27 18:18:34 barbier Exp $
+#
+# Copyright 2002 by Martin Quinson <Martin.Quinson@ens-lyon.fr>
 #
 # This program is free software; you may redistribute it and/or modify it
-# under the terms of GPL (see COPYING file).
+# under the terms of GPL (see COPYING).
 #
 # This module converts POD to PO file, so that it becomes possible to 
-# translate POD formatted documentation. See gettext documentation for
+# translate POD formated documentation. See gettext documentation for
 # more info about PO files.
 
 ############################################################################
@@ -23,51 +25,12 @@ use warnings;
 
 require Exporter;
 
-use vars qw(@ISA);
+use vars qw($VERSION @ISA);
+$VERSION=$Locale::Po4a::TransTractor::VERSION;
 @ISA = qw(Locale::Po4a::TransTractor Pod::Parser);
 
 sub initialize {}
 
-sub translate {
-    my ($self,$str,$ref,$type) = @_;
-    my (%options)=@_;
-
-    $str = $self->pre_trans($str,$ref,$type);
-    $str = $self->SUPER::translate($str, $ref, $type, %options);
-    $str = $self->post_trans($str,$ref,$type);
-
-    return $str;
-}
-
-sub pre_trans {
-    my ($self,$str,$ref,$type)=@_;
-
-    return $str;
-}
-
-sub post_trans {
-    my ($self,$str,$ref,$type)=@_;
-
-    # Change ascii non-breaking space to POD one
-    my $nbs_out = "\xA0";
-    my $enc_length = Encode::from_to($nbs_out, "latin1",
-                                               $self->get_out_charset);
-    if (defined $enc_length) {
-        while ($str =~ m/(^|.*\s)(\S+?)\Q$nbs_out\E(\S+?)(\s.*$|$)/s) {
-            my ($begin, $m1, $m2, $end) = ($1, $2, $3, $4);
-            $str  = (defined $begin)?$begin:"";
-            # Remove the non-breaking spaces in the string that will be
-            # between S<...>
-            $m2 =~ s/\Q$nbs_out\E/ /g;
-            $str .= "S<$m1 $m2>";
-            $str .= (defined $end)?$end:"";
-        }
-    }
-
-    return $str;
-}
-
-
 sub command {
     my ($self, $command, $paragraph, $line_num) = @_;
 #    print STDOUT "cmd: '$command' '$paragraph' at $line_num\n";
@@ -82,7 +45,7 @@ sub command {
 				    $self->input_file().":$line_num",
 				    "=$command",
 				    "wrap"=>1);
-	$self->pushline("=$command $paragraph\n\n");
+	$self->pushline("=$command $paragraph\n");
     }
 }
 
@@ -127,7 +90,7 @@ sub textblock {
 				'textblock',
 				"wrap"=>1);
     $paragraph=~ s/ +\n/\n/gm;
-    $self->pushline("$paragraph\n\n");
+    $self->pushline("$paragraph\n");
 }
 
 sub end_pod {}
@@ -145,14 +108,6 @@ sub parse {
 }
 
 sub docheader {
-    my $self=shift;
-    my $encoding = $self->{TT}{file_out_charset};
-    if (defined $encoding and length $encoding) {
-        $encoding = "\n=encoding $encoding\n";
-    } else {
-        $encoding = "";
-    }
-
     return <<EOT;
 
         *****************************************************
@@ -161,11 +116,11 @@ sub docheader {
         *****************************************************
 
 This file was generated by po4a(7). Do not store it (in cvs, for example),
-but store the po file used as source file by po4a-translate. 
+but store the po file used as source file by pod-translate. 
 
 In fact, consider this as a binary, and the po file as a regular .c file:
 If the po get lost, keeping this translation up-to-date will be harder.
-$encoding
+
 EOT
 }
 1;
@@ -216,10 +171,10 @@ and mine contain
 
  "" #n""
  
-which is logic since C<foobar> is rewritten "foobar"
+which is logic since C<blabla> is rewritten "blabla"
 
 Complete list of pages having this problem on my box (from 564 pages ; note
-that it depends on the chosen wrapping column):
+that it depend on the choosen wrapping colon):
 /usr/lib/perl5/Tk/MainWindow.pod
 /usr/share/perl/5.8.0/overload.pod
 /usr/share/perl/5.8.0/pod/perlapi.pod
@@ -302,13 +257,13 @@ L<Locale::Po4a::Man(3pm)>,
 =head1 AUTHORS
 
  Denis Barbier <barbier@linuxfr.org>
- Martin Quinson (mquinson#debian.org)
+ Martin Quinson <martin.quinson@tuxfamily.org>
 
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2002 by SPI, inc.
 
 This program is free software; you may redistribute it and/or modify it
-under the terms of GPL (see the COPYING file).
+under the terms of GPL (see COPYING file).
 
 =cut
