@@ -3,7 +3,6 @@
 require Exporter;
 
 package Locale::Po4a::TransTractor;
-use DynaLoader;
 
 use 5.006;
 use strict;
@@ -11,38 +10,33 @@ use warnings;
 
 use subs qw(makespace);
 use vars qw($VERSION @ISA @EXPORT);
-$VERSION="0.40.2";
-@ISA = qw(DynaLoader);
-@EXPORT = qw(new process translate 
-             read write readpo writepo
-             getpoout setpoout get_out_charset);
-
-# Try to use a C extension if present.
-eval("bootstrap Locale::Po4a::TransTractor $VERSION");
+$VERSION="0.19";
+@ISA = ();
+@EXPORT = qw(process translate 
+	     read write readpo writepo
+             getpoout setpoout);
 
 use Carp qw(croak);
 use Locale::Po4a::Po;
-use Locale::Po4a::Common;
 
+use Locale::gettext qw(dgettext);
 use File::Path; # mkdir before write
 
 use Encode;
 use Encode::Guess;
 
-=encoding UTF-8
-
 =head1 NAME
 
-Locale::Po4a::TransTractor - generic trans(lator ex)tractor.
+Po4a TransTractor - Generic trans(lator ex)tractor.
 
 =head1 DESCRIPTION
 
-The po4a (PO for anything) project goal is to ease translations (and more
+The po4a (po for anything) project goal is to ease translations (and more
 interestingly, the maintenance of translations) using gettext tools on
 areas where they were not expected like documentation.
 
 This class is the ancestor of every po4a parsers used to parse a document to
-search translatable strings, extract them to a PO file and replace them by
+search translatable strings, extract them to a po file and replace them by
 their translation in the output document. 
 
 More formally, it takes the following arguments as input:
@@ -55,7 +49,7 @@ a document to translate ;
 
 =item -
 
-a PO file containing the translations to use.
+a po file containing the translations to use.
 
 =back
 
@@ -65,14 +59,14 @@ As output, it produces:
 
 =item -
 
-another PO file, resulting of the extraction of translatable strings from
+another po file, resulting of the extraction of translatable strings from
 the input document ;
 
 =item -
 
 a translated document, with the same structure than the one in input, but
 with all translatable strings replaced with the translations found in the
-PO file provided in input.
+po file provided in input.
 
 =back
 
@@ -82,7 +76,7 @@ Here is a graphical representation of this:
                      \                           /       (translated)
                       +-> parse() function -----+
                      /                           \
-   Input PO --------/                             \---> Output PO
+   Input po --------/                             \---> Output po
                                                          (extracted)
 
 =head1 FUNCTIONS YOUR PARSER SHOULD OVERRIDE
@@ -94,10 +88,10 @@ Here is a graphical representation of this:
 This is where all the work takes place: the parsing of input documents, the
 generation of output, and the extraction of the translatable strings. This
 is pretty simple using the provided functions presented in the section
-B<INTERNAL FUNCTIONS> below. See also the B<SYNOPSIS>, which present an
+"INTERNAL FUNCTIONS" below. See also the synopsis, which present an
 example.
 
-This function is called by the process() function below, but if you choose
+This function is called by the process() function bellow, but if you choose
 to use the new() function, and to add content manually to your document,
 you will have to call this function yourself.
 
@@ -105,7 +99,7 @@ you will have to call this function yourself.
 
 This function returns the header we should add to the produced document,
 quoted properly to be a comment in the target language.  See the section
-B<Educating developers about translations>, from L<po4a(7)|po4a.7>, for what
+"Educating developers about translations", from L<po4a(7)|po4a.7>, for what
 it is good for.
 
 =back
@@ -118,24 +112,21 @@ sub parse {}
 
 =head1 SYNOPSIS
 
-The following example parses a list of paragraphs beginning with "<p>". For the sake
-of simplicity, we assume that the document is well formatted, i.e. that '<p>'
-tags are the only tags present, and that this tag is at the very beginning
+The following example parses a list of paragraphs begining with "<p>". For sake
+of simplicity, we assume that the document is well formatted, ie that '<p>'
+tags are the only tags present, and that this tag is at the very begining
 of each paragraph.
 
  sub parse {
-   my $self = shift;
-
    PARAGRAPH: while (1) {
-       my ($paragraph,$pararef)=("","");
-       my $first=1;
-       my ($line,$lref)=$self->shiftline();
-       while (defined($line)) {
+       $my ($paragraph,$pararef,$line,$lref)=("","","","");
+       $my $first=1;
+       while (($line,$lref)=$document->shiftline() && defined($line)) {
 	   if ($line =~ m/<p>/ && !$first--; ) {
 	       # Not the first time we see <p>. 
 	       # Reput the current line in input,
 	       #  and put the built paragraph to output
-	       $self->unshiftline($line,$lref);
+	       $document->unshiftline($line,$lref);
 	      
 	       # Now that the document is formed, translate it:
 	       #   - Remove the leading tag
@@ -143,9 +134,9 @@ of each paragraph.
 
 	       #   - push to output the leading tag (untranslated) and the
 	       #     rest of the paragraph (translated)
-	       $self->pushline(  "<p>"
-                               . $document->translate($paragraph,$pararef)
-                               );
+	       $document->pushline(  "<p>"
+                                   . $document->translate($paragraph,$pararef)
+                                   );
 
  	       next PARAGRAPH;
 	   } else {
@@ -153,11 +144,8 @@ of each paragraph.
 	       $paragraph .= $line;
 	       $pararef = $lref unless(length($pararef));
 	   }
-
-           # Reinit the loop
-           ($line,$lref)=$self->shiftline();
        }
-       # Did not get a defined line? End of input file.
+       # Did not got a defined line? End of input file.
        return;
    }
  } 
@@ -180,7 +168,7 @@ invocation. Its arguments must be packed as a hash. ACTIONS:
 
 =item a.
 
-Reads all the PO files specified in po_in_name
+Reads all the po files specified in po_in_name
 
 =item b.
 
@@ -192,7 +180,7 @@ Parses the document
 
 =item d.
 
-Reads and applies all the addenda specified
+Reads and applies all the addendum specified
 
 =item e.
 
@@ -200,7 +188,7 @@ Writes the translated document to file_out_name (if given)
 
 =item f.
 
-Writes the extracted PO file to po_out_name (if given)
+Writes the extracted po file to po_out_name (if given)
 
 =back
 
@@ -224,31 +212,31 @@ Filename where we should write the output document.
 =item file_out_charset ($)
 
 Charset used in the output document (if it isn't specified, it will use
-the PO file charset).
+the po file charset).
 
 =item po_in_name (@)
 
-List of filenames where we should read the input PO files from, containing
+List of filenames where we should read the input po files from, containing
 the translation which will be used to translate the document.
 
 =item po_out_name ($)
 
-Filename where we should write the output PO file, containing the strings
+Filename where we should write the output po file, containing the strings
 extracted from the input document.
 
 =item addendum (@)
 
-List of filenames where we should read the addenda from.
+list of filenames where we should read the addendum from.
 
 =item addendum_charset ($)
 
-Charset for the addenda.
+Charset for the addendum.
 
 =back
 
 =item new(%)
 
-Create a new po4a document. Accepted options (but be in a hash):
+Create a new Po4a document. Accepted options (but be in a hash):
 
 =over 4
 
@@ -286,16 +274,10 @@ sub process {
 	$newparams{$_}=$params{$_};
     }
 
-    $self->detected_charset($params{'file_in_charset'});
+    $self->{TT}{'file_in_charset'}=$params{'file_in_charset'};
     $self->{TT}{'file_out_charset'}=$params{'file_out_charset'};
-    if (defined($self->{TT}{'file_out_charset'}) and
-	length($self->{TT}{'file_out_charset'})) {
-	$self->{TT}{'file_out_encoder'} = find_encoding($self->{TT}{'file_out_charset'});
-    }
     $self->{TT}{'addendum_charset'}=$params{'addendum_charset'};
 
-    chdir $params{'srcdir'}
-	if (defined $params{'srcdir'});
     foreach my $file (@{$params{'po_in_name'}}) {
 	print STDERR "readpo($file)... " if $self->debug();
 	$self->readpo($file);
@@ -314,24 +296,18 @@ sub process {
 	$self->addendum($file) || die "An addendum failed\n";
 	print STDERR "done.\n" if $self->debug();
     }
-    chdir $params{'destdir'}
-	if (defined $params{'destdir'});
     if (defined $params{'file_out_name'}) {
 	print STDERR "write(".$params{'file_out_name'}.")... " 
 	    if $self->debug();
 	$self->write($params{'file_out_name'});
 	print STDERR "done.\n" if $self->debug();
     }
-    chdir $params{'srcdir'}
-	if (defined $params{'srcdir'});
     if (defined $params{'po_out_name'}) {
 	print STDERR "writepo(".$params{'po_out_name'}.")... "
 	     if $self->debug();
 	$self->writepo($params{'po_out_name'});
 	print STDERR "done.\n" if $self->debug();
     }
-    chdir $params{'calldir'}
-	if (defined $params{'calldir'});
     return $self;
 }
 
@@ -344,28 +320,11 @@ sub new {
     ## Bless ourselves into the desired class and perform any initialization
     bless $self, $class;
     
-    ## initialize the plugin
-    # prevent the plugin from croaking on the options intended for Po.pm
-    $self->{options}{'porefs'} = '';
-    $self->{options}{'copyright-holder'} = '';
-    $self->{options}{'msgid-bugs-address'} = '';
-    $self->{options}{'package-name'} = '';
-    $self->{options}{'package-version'} = '';
-    # let the plugin parse the options and such
-    $self->initialize(%options);
-
     ## Create our private data
-    my %po_options;
-    $po_options{'porefs'} = $self->{options}{'porefs'};
-    $po_options{'copyright-holder'} = $options{'copyright-holder'};
-    $po_options{'msgid-bugs-address'} = $options{'msgid-bugs-address'};
-    $po_options{'package-name'} = $options{'package-name'};
-    $po_options{'package-version'} = $options{'package-version'};
-    
     # private data
     $self->{TT}=(); 
-    $self->{TT}{po_in}=Locale::Po4a::Po->new(\%po_options);
-    $self->{TT}{po_out}=Locale::Po4a::Po->new(\%po_options);
+    $self->{TT}{po_in}=Locale::Po4a::Po->new();
+    $self->{TT}{po_out}=Locale::Po4a::Po->new();
     # Warning, this is an array of array:
     #  The document is splited on lines, and for each
     #  [0] is the line content, [1] is the reference [2] the type
@@ -383,6 +342,8 @@ sub new {
     # document isn't in ascii)
     $self->{TT}{utf_mode}=0;
 
+    ## initialize the plugin
+    $self->initialize(%options);
     
     return $self;
 }
@@ -407,32 +368,30 @@ function when you're done with packing input files into the document.
 sub read() {
     my $self=shift;
     my $filename=shift
-	or croak wrap_msg(dgettext("po4a", "Can't read from file without having a filename"));
+	or croak(dgettext("po4a","Can't read from file without having a filename")."\n");
     my $linenum=0;
 
     open INPUT,"<$filename" 
-	or croak wrap_msg(dgettext("po4a", "Can't read from %s: %s"), $filename, $!);
+	or croak (sprintf(dgettext("po4a","Can't read from %s: %s"),$filename,$!)."\n");
     while (defined (my $textline = <INPUT>)) {
 	$linenum++;
 	my $ref="$filename:$linenum";
 	my @entry=($textline,$ref);
 	push @{$self->{TT}{doc_in}}, @entry;
 
-	if (!defined($self->{TT}{'file_in_charset'})) {
-	    # Detect if this file has non-ascii characters
-	    if($self->{TT}{ascii_input}) {
-		my $decoder = guess_encoding($textline);
-		if (!ref($decoder) or $decoder !~ /Encode::XS=/) {
-		    # We have detected a non-ascii line
-		    $self->{TT}{ascii_input} = 0;
-		    # Save the reference for future error message
-		    $self->{TT}{non_ascii_ref} ||= $ref;
-		}
+	# Detect if this file has non-ascii characters
+	if($self->{TT}{ascii_input}) {
+	    my $decoder = guess_encoding($textline);
+	    if (!ref($decoder) or $decoder !~ /Encode::XS=/) {
+	        # We have detected a non-ascii line
+		$self->{TT}{ascii_input} = 0;
+		# Save the reference for future error message
+		$self->{TT}{non_ascii_ref} ||= $ref;
 	    }
 	}
     }
     close INPUT 
-	or croak wrap_msg(dgettext("po4a", "Can't close %s after reading: %s"), $filename, $!);
+	or croak (sprintf(dgettext("po4a","Can't close %s after reading: %s"),$filename,$!)."\n");
 
 }
 
@@ -445,7 +404,7 @@ Write the translated document to the given filename.
 sub write {
     my $self=shift;
     my $filename=shift
-	or croak wrap_msg(dgettext("po4a", "Can't write to a file without filename"));
+	or croak (dgettext("po4a","Can't write to a file without filename")."\n");
 
     my $fh;
     if ($filename eq '-') {
@@ -460,40 +419,40 @@ sub write {
 	      if (length ($dir) && ! -e $dir);
 	}
 	open $fh,">$filename"
-	    or croak wrap_msg(dgettext("po4a", "Can't write to %s: %s"), $filename, $!);
+	    || croak (sprintf((dgettext("po4a","can't write to %s: %s"),$filename,$!))."\n");
     }
     
     map { print $fh $_ } $self->docheader();
     map { print $fh $_ } @{$self->{TT}{doc_out}};
 
     if ($filename ne '-') {
-	close $fh or croak wrap_msg(dgettext("po4a", "Can't close %s after writing: %s"), $filename, $!);
+	close $fh || croak (sprintf(dgettext("po4a","Can't close %s after writing: %s"),$filename,$!)."\n");
     }
 
 }
 
 =back
 
-=head2 Manipulating PO files
+=head2 Manipulating po files
 
 =over 4 
 
 =item readpo($)
 
 Add the content of a file (which name is passed in argument) to the
-existing input PO. The old content is not discarded.
+existing input po. The old content is not discarded.
 
 =item writepo($)
 
-Write the extracted PO file to the given filename.
+Write the extracted po file to the given filename.
 
 =item stats()
 
 Returns some statistics about the translation done so far. Please note that
 it's not the same statistics than the one printed by msgfmt
---statistic. Here, it's stats about recent usage of the PO file, while
+--statistic. Here, it's stats about recent usage of the po file, while
 msgfmt reports the status of the file. It is a wrapper to the
-Locale::Po4a::Po::stats_get function applied to the input PO file. Example
+Locale::Po4a::Po::stats_get function applied to the input po file. Example
 of use:
 
     [normal use of the po4a document...]
@@ -521,17 +480,19 @@ sub stats   {
     return $_[0]->{TT}{po_in}->stats_get(); 
 }
 
-=head2 Manipulating addenda
+=cut
+
+=head2 Manipulating addendum
 
 =over 4
 
 =item addendum($)
 
-Please refer to L<po4a(7)|po4a.7> for more information on what addenda are,
+Please refer to L<po4a(7)|po4a.7> for more information on what addendum are,
 and how translators should write them. To apply an addendum to the translated
 document, simply pass its filename to this function and you are done ;)
 
-This function returns a non-null integer on error.
+This function returns a non-nul integer on error.
 
 =cut
 
@@ -543,22 +504,25 @@ sub addendum_parse {
 	(1,"","","","","");
 
     unless (open (INS, "<$filename")) {
-	warn wrap_msg(dgettext("po4a", "Can't read from %s: %s"), $filename, $!);
+	warn sprintf(dgettext("po4a","Can't read from %s: %s"),$filename,$!)."\n";
 	goto END_PARSE_ADDFILE;
     } 
 
     unless (defined ($header=<INS>) && $header)  {
-	warn wrap_msg(dgettext("po4a", "Can't read po4a header from %s."), $filename);
+	warn sprintf(dgettext("po4a","Can't read Po4a header from %s."),
+		     $filename)."\n";
 	goto END_PARSE_ADDFILE;
     }
 
     unless ($header =~ s/PO4A-HEADER://i) {
-	warn wrap_msg(dgettext("po4a", "First line of %s does not look like a po4a header."), $filename);
+	warn sprintf(dgettext("po4a","First line of %s does not look like a Po4a header."),
+		     $filename)."\n";
 	goto END_PARSE_ADDFILE;
     }
     foreach my $part (split(/;/,$header)) {
 	unless ($part =~ m/^\s*([^=]*)=(.*)$/) {
-	    warn wrap_msg(dgettext("po4a", "Syntax error in po4a header of %s, near \"%s\""), $filename, $part);
+	    warn sprintf(dgettext("po4a","Syntax error in Po4a header of %s, near \"%s\""),
+			 $filename,$part)."\n";
 	    goto END_PARSE_ADDFILE;
 	}
 	my ($key,$value)=($1,$2);
@@ -572,26 +536,30 @@ sub addendum_parse {
 	    $boundary=$value;
 	    $bmode='before';
 	} else { 
-	    warn wrap_msg(dgettext("po4a", "Invalid argument in the po4a header of %s: %s"), $filename, $key);
+	    warn sprintf(dgettext("po4a","Invalid argument in the Po4a header of %s: %s"),
+			 $filename,$key)."\n";
 	    goto END_PARSE_ADDFILE;
 	}
     }
 
     unless (length($mode)) {
-	warn wrap_msg(dgettext("po4a", "The po4a header of %s does not define the mode."), $filename);
+	warn sprintf(dgettext("po4a","The Po4a header of %s does not define the mode."),
+		     $filename)."\n";
 	goto END_PARSE_ADDFILE;
     }
     unless ($mode eq "before" || $mode eq "after") {
-	warn wrap_msg(dgettext("po4a", "Mode invalid in the po4a header of %s: should be 'before' or 'after' not %s."), $filename, $mode);
+	warn sprintf(dgettext("po4a","Mode invalid in the Po4a header of %s: should be 'before' or 'after' not %s."),
+		     $filename,$mode)."\n";
 	goto END_PARSE_ADDFILE;
     }
 
     unless (length($position)) {
-	warn wrap_msg(dgettext("po4a", "The po4a header of %s does not define the position."), $filename);
+	warn sprintf(dgettext("po4a","The Po4a header of %s does not define the position."),
+		     $filename)."\n";
 	goto END_PARSE_ADDFILE;
     }
     unless ($mode eq "before" || length($boundary)) {
-    	warn wrap_msg(dgettext("po4a", "No ending boundary given in the po4a header, but mode=after."));
+    	warn dgettext("po4a","No ending boundary given in the Po4a header, but mode=after.")."\n";
 	goto END_PARSE_ADDFILE;
     }
 
@@ -616,11 +584,11 @@ sub addendum {
 
     print STDERR "Apply addendum $filename..." if $self->debug();
     unless ($filename) {
-	warn wrap_msg(dgettext("po4a",
-	    "Can't apply addendum when not given the filename"));
+	warn(dgettext("po4a",
+	    "Can't apply addendum when not given the filename")."\n");
 	return 0;
     }
-    die wrap_msg(dgettext("po4a", "Addendum %s does not exist."), $filename)
+    die sprintf(dgettext("po4a","Addendum %s does not exist.")."\n",$filename)
       unless -e $filename;
   
     my ($errcode,$mode,$position,$boundary,$bmode,$content)=
@@ -640,19 +608,22 @@ sub addendum {
 
     my $found = scalar grep { /$position/ } @{$self->{TT}{doc_out}};
     if ($found == 0) {
-	warn wrap_msg(dgettext("po4a",
-	    "No candidate position for the addendum %s."), $filename);
+	warn sprintf(dgettext("po4a",
+			      "No candidate position for the addendum %s."),
+		     $filename)."\n";
 	return 0;
     }
     if ($found > 1) {
-	warn wrap_msg(dgettext("po4a",
-	    "More than one candidate position found for the addendum %s."), $filename);
+	warn sprintf(dgettext("po4a",
+			      "More than one cadidate position found for the addendum %s."),
+		     $filename)."\n";
 	return 0;
     }
 
     if ($mode eq "before") {
 	if ($self->verbose() > 1 || $self->debug() ) {
-	    map { print STDERR wrap_msg(dgettext("po4a", "Addendum '%s' applied before this line: %s"), $filename, $_) if (/$position/);
+	    map { print STDERR sprintf(dgettext("po4a","Addendum '%s' applied before this line: %s"),
+			 $filename,$_)."\n" if (/$position/);
  	        } @{$self->{TT}{doc_out}};
 	}
 	@{$self->{TT}{doc_out}} = map { /$position/ ? ($content,$_) : $_ 
@@ -674,22 +645,23 @@ sub addendum {
 		}
 		if (defined $line) {
 		    if ($bmode eq 'before') {
-			print wrap_msg(dgettext("po4a",
-			    "Addendum '%s' applied before this line: %s"),
-			    $filename, $outline)
+			print sprintf (dgettext("po4a",
+			    "Addendum '%s' applied before this line: %s")."\n",
+			    $filename,$outline)
 			  if ($self->verbose() > 1 || $self->debug());
 			push @newres,$content;
 			push @newres,$line;
 		    } else {
-			print wrap_msg(dgettext("po4a",
-			    "Addendum '%s' applied after the line: %s."),
-			    $filename, $outline)
+			print sprintf (dgettext("po4a",
+			    "Addendum '%s' applied after the line: %s.")."\n",
+			    $filename,$outline)
 			  if ($self->verbose() > 1 || $self->debug());
 			push @newres,$line;
 			push @newres,$content;
 		    }
 		} else {
-		    print wrap_msg(dgettext("po4a", "Addendum '%s' applied at the end of the file."), $filename)
+		    print sprintf (dgettext("po4a","Addendum '%s' applied at the end of the file.")."\n",
+		        $filename)
 		      if ($self->verbose() > 1 || $self->debug());
 		    push @newres,$content;
 		}
@@ -711,7 +683,7 @@ Four functions are provided to get input and return output. They are very
 similar to shift/unshift and push/pop. The first pair is about input, while
 the second is about output. Mnemonic: in input, you are interested in the
 first line, what shift gives, and in output you want to add your result at
-the end, like push does.
+the end, like pop does.
 
 =over 4
 
@@ -741,10 +713,7 @@ sub shiftline   {
 		     shift @{$_[0]->{TT}{doc_in}}); 
     return ($line,$ref);
 }
-sub unshiftline {
-	my $self = shift;
-	unshift @{$self->{TT}{doc_in}},@_;
-}
+sub unshiftline {  unshift @{$_[0]->{TT}{doc_in}},($_[1],$_[2]);  }
 
 sub pushline    {  push @{$_[0]->{TT}{doc_out}}, $_[1] if defined $_[1]; }
 sub popline     {  return pop @{$_[0]->{TT}{doc_out}};            }
@@ -773,7 +742,7 @@ The reference of this string (ie, position in inputfile)
 
 The type of this string (ie, the textual description of its structural role
 ; used in Locale::Po4a::Po::gettextization() ; see also L<po4a(7)|po4a.7>,
-section B<Gettextization: how does it work?>)
+section I<Gettextization: how does it work?>)
 
 =back
 
@@ -785,19 +754,19 @@ a hash. For example:
 
 =over
 
-=item B<wrap>
+=item wrap
 
-boolean indicating whether we can consider that whitespaces in string are
-not important. If yes, the function canonizes the string before looking for
+boolean indicating wheather we can consider that whitespaces in string are
+not important. If yes, the function canonize the string before looking for
 a translation or extracting it, and wraps the translation.
 
-=item B<wrapcol>
+=item wrapcol
 
-the column at which we should wrap (default: 76).
+The column at which we should wrap (default: 76).
 
-=item B<comment>
+=item comment
 
-an extra comment to add to the entry.
+An extra comment to add to the entry.
 
 =back
 
@@ -847,37 +816,23 @@ sub translate {
     } else {
 	if (defined($self->{TT}{'file_in_charset'}) and
 	    length($self->{TT}{'file_in_charset'}) and
-	    $self->{TT}{'file_in_charset'} !~ m/ascii/i) {
+	    $self->{TT}{'file_in_charset'} ne "CHARSET" and
+	    $self->{TT}{'file_in_charset'} ne "ascii") {
 	    $in_charset=$self->{TT}{'file_in_charset'};
 	} else {
 	    # FYI, the document charset have to be determined *before* we see the first
 	    # string to recode.
-	    die wrap_mod("po4a", dgettext("po4a", "Couldn't determine the input document's charset. Please specify it on the command line. (non-ASCII char at %s)"), $self->{TT}{non_ascii_ref})
+	    die "po4a: ".sprintf(dgettext("po4a","Couldn't determine the input document's charset. Please specify it on the command line. (non-ascii char at %s)"),$self->{TT}{non_ascii_ref})."\n"
 	}
     }
 
-    if ($self->{TT}{po_in}->get_charset ne "CHARSET") {
-	$string = encode_from_to($string,
-	                         $self->{TT}{'file_in_encoder'},
-	                         $self->{TT}{po_in}{encoder});
-    }
-
-    if (defined $options{'wrapcol'} && $options{'wrapcol'} < 0) {
-# FIXME: should be the parameter given with --width
-        $options{'wrapcol'} = 76 + $options{'wrapcol'};
-    }
     my $transstring = $self->{TT}{po_in}->gettext($string,
 					'wrap'      => $options{'wrap'}||0,
 					'wrapcol'   => $options{'wrapcol'});
 
     if ($self->{TT}{po_in}->get_charset ne "CHARSET") {
-	my $out_encoder = $self->{TT}{'file_out_encoder'};
-	unless (defined $out_encoder) {
-	    $out_encoder = find_encoding($self->get_out_charset)
-	}
-	$transstring = encode_from_to($transstring,
-	                              $self->{TT}{po_in}{encoder},
-	                              $out_encoder);
+	Encode::from_to($transstring,$self->{TT}{po_in}->get_charset,
+	    $self->get_out_charset);
     }
 
     # If the input document isn't completely in ascii, we should see what to
@@ -887,7 +842,7 @@ sub translate {
 	# We set the output po charset 
         if ($out_charset eq "CHARSET") {
 	    if ($self->{TT}{utf_mode}) {
-		$out_charset="UTF-8";
+		$out_charset="utf-8";
 	    } else {
 		$out_charset=$in_charset;
 	    }
@@ -895,9 +850,6 @@ sub translate {
 	}
 	if ( $in_charset !~ /^$out_charset$/i ) {
 	    Encode::from_to($string,$in_charset,$out_charset);
-	    if (defined($options{'comment'}) and length($options{'comment'})) {
-		Encode::from_to($options{'comment'},$in_charset,$out_charset);
-	    }
 	}
     }
 
@@ -905,7 +857,7 @@ sub translate {
     $self->{TT}{po_out}->push('msgid'     => $string,
 			      'reference' => $ref,
 			      'type'      => $type,
-	                      'automatic' => $options{'comment'},
+	                      'automatic' => $options{'comment'}||"",
 			      'wrap'      => $options{'wrap'}||0,
 			      'wrapcol'   => $options{'wrapcol'});
 
@@ -913,14 +865,6 @@ sub translate {
 #	Encode::from_to($transstring,$self->{TT}{po_in}->get_charset,
 #	    $self->get_out_charset);
 #    }
-
-    if ($options{'wrap'}||0) {
-        $transstring =~ s/( *)$//s;
-        my $trailing_spaces = $1||"";
-        $transstring =~ s/(?<!\\) +$//gm;
-        $transstring .= $trailing_spaces;
-    }
-
     return $transstring;
 }
 
@@ -966,20 +910,9 @@ process() arguments or detected from the document.
 sub detected_charset {
     my ($self,$charset)=(shift,shift);
     unless (defined($self->{TT}{'file_in_charset'}) and
-            length($self->{TT}{'file_in_charset'}) ) {
-        $self->{TT}{'file_in_charset'}=$charset;
-        if (defined $charset) {
-            $self->{TT}{'file_in_encoder'}=find_encoding($charset);
-        } else {
-            $self->{TT}{ascii_input}=1;
-            $self->{TT}{utf_mode}=0;
-        }
-    }
+	length($self->{TT}{'file_in_charset'}) ) {
 
-    if (defined $self->{TT}{'file_in_charset'} and
-        length $self->{TT}{'file_in_charset'} and
-        $self->{TT}{'file_in_charset'} !~ m/ascii/i) {
-	$self->{TT}{ascii_input}=0;
+	$self->{TT}{'file_in_charset'}=$charset;
     }
 }
 
@@ -990,7 +923,7 @@ document (usually useful to substitute the input document's detected charset
 where it has been found).
 
 It will use the output charset specified in the command line. If it wasn't
-specified, it will use the input PO's charset, and if the input PO has the
+specified, it will use the input po's charset, and if the input po has the
 default "CHARSET", it will return the input document's charset, so that no
 encoding is performed.
 
@@ -1006,7 +939,7 @@ sub get_out_charset {
 	$charset=$self->{TT}{'file_out_charset'};
     } else {
 	if ($self->{TT}{utf_mode} && $self->{TT}{ascii_input}) {
-	    $charset="UTF-8";
+	    $charset="utf-8";
 	} else {
 	    $charset=$self->{TT}{po_in}->get_charset;
 	    $charset=$self->{TT}{'file_in_charset'}
@@ -1035,48 +968,15 @@ sub recode_skipped_text {
     unless ($self->{TT}{'ascii_input'}) {
 	if(defined($self->{TT}{'file_in_charset'}) and
 	    length($self->{TT}{'file_in_charset'}) ) {
-	    $text = encode_from_to($text,
-	                           $self->{TT}{'file_in_encoder'},
-	                           find_encoding($self->get_out_charset));
+	    Encode::from_to($text,$self->{TT}{'file_in_charset'},
+		$self->get_out_charset);
 	} else {
-	    die wrap_mod("po4a", dgettext("po4a", "Couldn't determine the input document's charset. Please specify it on the command line. (non-ASCII char at %s)"), $self->{TT}{non_ascii_ref})
+	    die "po4a: ".sprintf(dgettext("po4a","Couldn't determine the input document's charset. Please specify it on the command line. (non-ascii char at %s)"),$self->{TT}{non_ascii_ref})."\n"
 	}
     }
     return $text;
 }
 
-
-# encode_from_to($,$,$)
-#
-# Encode the given text from one encoding to another one.
-# It differs from Encode::from_to because it does not take the name of the
-# encoding in argument, but the encoders (as returned by the
-# Encode::find_encoding(<name>) method). Thus it permits to save a bunch
-# of call to find_encoding.
-#
-# If the "from" encoding is undefined, it is considered as UTF-8 (or
-# ascii).
-# If the "to" encoding is undefined, it is considered as UTF-8.
-#
-sub encode_from_to {
-    my ($text,$from,$to) = (shift,shift,shift);
-
-    if (not defined $from) {
-        # for ascii and UTF-8, no conversion needed to get an utf-8
-        # string.
-    } else {
-        $text = $from->decode($text, 0);
-    }
-
-    if (not defined $to) {
-        # Already in UTF-8, no conversion needed
-    } else {
-        $text = $to->encode($text, 0);
-    }
-
-    return $text;
-}
-
 =back
 
 =head1 FUTURE DIRECTIONS
@@ -1089,9 +989,9 @@ To address this problem, the only interface changes needed are:
 
 =over 2
 
-=item -
+=item - 
 
-take a hash as po_in_name (a list per language)
+take an hash as po_in_name (a list per language)
 
 =item -
 
@@ -1113,8 +1013,8 @@ Will see if it's enough ;)
 =head1 AUTHORS
 
  Denis Barbier <barbier@linuxfr.org>
- Martin Quinson (mquinson#debian.org)
- Jordi Vilalta <jvprat@gmail.com>
+ Martin Quinson <martin.quinson@tuxfamily.org>
+ Jordi Vilalta <jvprat@wanadoo.es>
 
 =cut
 
